==> chromium_143.0.7499.169.orig.tar.xz: chromium-143.0.7499.169/cc/input/scroll_utils.cc <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "cc/input/scroll_utils.h"

#include <algorithm>

#include "ui/gfx/geometry/size_f.h"
#include "ui/gfx/geometry/vector2d_f.h"

namespace cc {

// static
gfx::Vector2dF ScrollUtils::ResolveScrollPercentageToPixels(
    const gfx::Vector2dF& delta,
    const gfx::SizeF& scroller,
    const gfx::SizeF& viewport) {
  // Work with unsigned values and keep sign information in sign_x / sign_y.
  float sign_x = std::signbit(delta.x()) ? -1 : 1;
  float sign_y = std::signbit(delta.y()) ? -1 : 1;
  float delta_x = std::abs(delta.x());
  float delta_y = std::abs(delta.y());

  // Resolve and clamp horizontal scroll
  if (delta_x > 0)
    delta_x =
        std::max(1.0f, delta_x * std::min(scroller.width(), viewport.width()));

  // Resolve and clamps vertical scroll.
  if (delta_y > 0)
    delta_y = std::max(
        1.0f, delta_y * std::min(scroller.height(), viewport.height()));

  return gfx::Vector2dF(std::copysign(delta_x, sign_x),
                        std::copysign(delta_y, sign_y));
}

// static
int ScrollUtils::CalculateMinPageSnap(int length) {
  const int min_page_step = length * kMinFractionToStepWhenSnapPaging;
  return std::max(min_page_step, 1);
}

// static
int ScrollUtils::CalculateMaxPageSnap(int length) {
  return std::max(length, 1);
}

// static
int ScrollUtils::CalculatePageStep(int length) {
  const int min_page_step = length * kMinFractionToStepWhenPaging;
  const int page_step =
      std::max(min_page_step, length - kMaxOverlapBetweenPages);
  return std::max(page_step, 1);
}

}  // namespace cc

==> chromium_144.0.7559.59.orig.tar.xz: chromium-144.0.7559.59/cc/input/scroll_utils.cc <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "cc/input/scroll_utils.h"

#include <algorithm>

#include "ui/gfx/geometry/size_f.h"
#include "ui/gfx/geometry/vector2d_f.h"

namespace cc {

// static
gfx::Vector2dF ScrollUtils::ResolveScrollPercentageToPixels(
    const gfx::Vector2dF& delta,
    const gfx::SizeF& scroller,
    const gfx::SizeF& viewport) {
  // Work with unsigned values and keep sign information in sign_x / sign_y.
  float sign_x = std::signbit(delta.x()) ? -1 : 1;
  float sign_y = std::signbit(delta.y()) ? -1 : 1;
  float delta_x = std::abs(delta.x());
  float delta_y = std::abs(delta.y());

  // Resolve and clamp horizontal scroll
  if (delta_x > 0)
    delta_x =
        std::max(1.0f, delta_x * std::min(scroller.width(), viewport.width()));

  // Resolve and clamps vertical scroll.
  if (delta_y > 0)
    delta_y = std::max(
        1.0f, delta_y * std::min(scroller.height(), viewport.height()));

  return gfx::Vector2dF(std::copysign(delta_x, sign_x),
                        std::copysign(delta_y, sign_y));
}

// static
int ScrollUtils::CalculateMinPageSnap(int length) {
  const int min_page_step = length * kMinFractionToStepWhenSnapPaging;
  return std::max(min_page_step, 1);
}

// static
int ScrollUtils::CalculateMaxPageSnap(int length) {
  return std::max(length, 1);
}

// static
int ScrollUtils::CalculatePageStep(int length) {
  const int min_page_step = length * kMinFractionToStepWhenPaging;
  const int page_step =
      std::max(min_page_step, length - kMaxOverlapBetweenPages);
  return std::max(page_step, 1);
}

// static
int ScrollUtils::CalculateScrollbarThumbLength(int total_size,
                                               int visible_size,
                                               int track_length,
                                               int minimum_thumb_length) {
  float proportion = 0.0f;
  if (total_size > 0) {
    proportion = static_cast<float>(visible_size) / total_size;
  }
  int length = round(proportion * track_length);
  length = std::max(length, minimum_thumb_length);
  if (length > track_length) {
    length = track_length;
  }
  return length;
}

}  // namespace cc
